# Playground for S3 services #

## Start local service ##

```sh
# Start S3 server, local storage in /data inside the container, no SSL.
docker run -p 9000:9000 -p 9001:9001 quay.io/minio/minio server /data --console-address ":9001"
```

The **default credentials** for the web interface are `minioadmin:minioadmin`, but this can be
changed via environment variables `MINIO_ROOT_USER` and `MINIO_ROOT_PASSWORD`.

## Create credentials ##

- Open http://localhost:9001/access-keys/new-account
- Set custom access key if desired, click "Create".
- Save credentials into `qualitycheck_secrets.toml` as `s3_access_key` and `s3_secret_key`.

## Create bucket ##

- Open http://localhost:9001/buckets/add-bucket
- Create bucket with custom name.

## Access with boto3 ##

```python
import boto3

# Verify connection
session = boto3.Session(aws_access_key_id="testaccount", aws_secret_access_key="SECRET")
client = session.client("s3", endpoint_url="http://localhost:9000")  # no SSL for testing!
client.list_buckets()

# Add content to bucket
client.upload_file(file_name, "testbucket", "some_name")
client.list_objects_v2(Bucket="testbucket")["Contents"]  # list contents

# Download object to filesystem
client.download_file("testbucket", "some_name", "./output_file")

# Delete objects in bucket
client.delete_object(Bucket="testbucket", Key="some name for later reference")
```

